@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.18.2.1 2000/06/13 08:32:57 fredgo Exp $
+# $Id: Editor.py,v 1.18.2.2 2000/07/24 09:39:32 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -474,11 +474,14 @@ class RealEditor (Connector.Publisher):
         self.w.pack_start (self.newfield_area, FALSE, FALSE)
         
         # Notebook
+        scroll = GtkScrolledWindow ()
+        scroll.set_policy (GTK.POLICY_AUTOMATIC, GTK.POLICY_AUTOMATIC)
         self.notebook = GtkNotebook ()
         self.notebook.show ()
 
-        self.w.pack_start (self.notebook)
-        self.w.show ()
+        scroll.add_with_viewport (self.notebook)
+        self.w.pack_start (scroll)
+        self.w.show_all ()
         
         self.notebook_init = FALSE
         self.update_notebook ()
