@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographic.py,v 1.4 2000/03/13 13:45:35 fredgo Exp $
+# $Id: pybliographic.py,v 1.5 2000/03/23 14:31:25 fredgo Exp $
 
 import sys
 
@@ -27,7 +27,7 @@ from gtk import *
 from Pyblio.GnomeUI.Pybliographic import Pybliographic
 from Pyblio.Fields import URL
 
-main = Pybliographic (version)
+main = Pybliographic ()
 
 if len (sys.argv) > 2:
     for file in sys.argv [2:]:
